@@ -2,13 +2,27 @@ def docs() -> str:
     return """
 Edita as informações de um atendimento avulso sistema existente no sistema SIGA.
 
+**INSTRUÇÃO PARA O AGENTE IA:**
+ANTES de executar esta função de edição:
+1. SEMPRE chame primeiro `buscar_informacoes_atendimento_avulso(codigo_atendimento, codigo_analista)`
+2. MOSTRE ao usuário os dados atuais vs. dados que serão alterados em formato claro e comparativo
+3. PEÇA confirmação explícita do usuário: "Confirma as alterações? (sim/não)"
+4. SÓ EXECUTE esta função se o usuário confirmar explicitamente
+5. Se o usuário não confirmar, cancele a operação e informe que foi cancelada
+
 Esta função permite atualizar todos os campos de um atendimento avulso sistema existente,
 incluindo datas, descrição, tipo, origem, sistema, equipe e projeto.
 Realiza validação de todos os campos obrigatórios e conversão automática de datas.
 
+**Funcionalidade de busca automática:**
+Se o atendimento não for encontrado nesta função (atendimentos avulso sistemas), a mensagem de erro orientará a buscar nas funções editar_atendimentos_os ou editar_atendimento_avulso_infraestrutura,
+permitindo busca automática entre os tipos de atendimento.
+
 **Endpoint utilizado:** `atualizarAtendimentoAvulsoSigaIA`
 
 **Estrutura do XML retornado:**
+
+**Sucesso:**
 ```xml
 <atendimentos_avulsos dataIni="2024-01-15 09:00:00" dataFim="2024-01-15 17:00:00"
                         matSolicitante="123456" tipo="19" descricao="Descrição"
@@ -20,7 +34,7 @@ Realiza validação de todos os campos obrigatórios e conversão automática de
 </atendimentos_avulsos>
 ```
 
-**Em caso de erro de validação:**
+**Em caso de erro de validação (campo inválido):**
 ```xml
 <erro_validacao sistema="SIGA" funcao="editar_atendimento_avulso_sistemas">
     <erro sistema="SIGA">
@@ -33,6 +47,30 @@ Realiza validação de todos os campos obrigatórios e conversão automática de
 </erro_validacao>
 ```
 
+**Em caso de erro (atendimento não encontrado):**
+```xml
+<atendimentos_avulsos codigo_atendimento="99999" dataIni="2024-01-15 09:00:00" dataFim="2024-01-15 17:00:00"
+                        matSolicitante="123456" tipo="19" descricao="Teste"
+                        origem="3" equipe="AVA" analista="789" projeto="73" sistema="271">
+    <atendimento_avulso sistema="SIGA">
+        <status>erro</status>
+        <mensagem>Atendimento não encontrado em Avulso Sistemas. Tente buscar nas funções editar_atendimentos_os ou editar_atendimento_avulso_infraestrutura.</mensagem>
+    </atendimento_avulso>
+</atendimentos_avulsos>
+```
+
+**Em caso de outros erros:**
+```xml
+<atendimentos_avulsos codigo_atendimento="123" dataIni="2024-01-15 09:00:00" dataFim="2024-01-15 17:00:00"
+                        matSolicitante="123456" tipo="19" descricao="Descrição"
+                        origem="3" equipe="AVA" analista="789" projeto="73" sistema="271">
+    <atendimento_avulso sistema="SIGA">
+        <status>erro</status>
+        <mensagem>Erro ao gravar o atendimento avulso. Tente novamente.</mensagem>
+    </atendimento_avulso>
+</atendimentos_avulsos>
+```
+
 Args:
     codigo_atendimento (int): Código único do atendimento avulso a ser editado
     data_inicio (str): Data e hora de início do atendimento avulso. Aceita formatos de data ou palavras-chave como "hoje", "agora", "ontem"
@@ -361,8 +399,9 @@ Args:
 Returns:
     str: XML formatado contendo:
         - Em caso de sucesso: confirmação da edição com status "sucesso"
-        - Em caso de erro de validação: detalhes do erro com valores válidos para o campo inválido
-        - Em caso de erro de API: mensagem de erro específica
+        - Em caso de atendimento não encontrado: status "erro" com orientação para buscar em outras funções
+        - Em caso de outros erros de validação: detalhes do erro com valores válidos para o campo inválido 
+        - Em caso de outros erros de API: status "erro" com mensagem explicativa
         - Em caso de erro interno: mensagem de erro genérica
 
         O XML sempre inclui os parâmetros enviados como atributos do elemento raiz.
@@ -397,6 +436,16 @@ Examples:
     ...     projeto="Operação Banco de Dados"
     ... )
 
+    >>> # Exemplo quando não encontra (orienta busca automática)
+    >>> xml = await editar_atendimento_avulso_sistemas(
+    ...     codigo_atendimento=99999,
+    ...     data_inicio="2024-01-15 09:00:00",
+    ...     data_fim="2024-01-15 17:00:00",
+    ...     matricula_solicitante="123456",
+    ...     descricao_atendimento="Teste",
+    ...     codigo_analista=789
+    ... )    
+
     >>> # Exemplo com tipo inválido (retorna erro)
     >>> xml = await editar_atendimento_avulso_sistemas(
     ...     codigo_atendimento=123,
@@ -409,11 +458,12 @@ Examples:
     ... )
 
 Notes:
-    - Esta função é específica para ÁREA SISTEMAS (área=1)
+    - **ATENÇÃO**: Esta operação modifica permanentemente os dados do atendimento
+    - **DIFERENCIAÇÃO DE TIPOS**: Esta função é específica para atendimentos avulso sistemas. Para outros tipos, use as funções específicas
+    - Para busca automática: Se não encontrar nesta função, use editar_atendimentos_os ou editar_atendimento_avulso_infraestrutura com os mesmos parâmetros
     - A função realiza validação case-insensitive de todos os campos (tipo, origem, sistema, equipe, projeto)
     - As datas são automaticamente convertidas usando converter_data_siga com manter_horas=True
-    - Utiliza as constantes: TIPO_TO_NUMBER_ATENDIMENTO_AVULSO, ORIGEM_TO_NUMBER, SISTEMA_TO_NUMBER,
-        EQUIPE_TO_NUMBER, PROJETO_TO_NUMBER para mapear valores para códigos numéricos
+    - Utiliza as constantes: TIPO_TO_NUMBER_ATENDIMENTO_AVULSO, ORIGEM_TO_NUMBER, SISTEMA_TO_NUMBER, EQUIPE_TO_NUMBER, PROJETO_TO_NUMBER para mapear valores para códigos numéricos
     - Todos os parâmetros enviados são incluídos como atributos no XML de resposta
     - A API key é obtida automaticamente da variável de ambiente AVA_API_KEY
     - Em caso de falha na requisição HTTP, retorna erro interno formatado em XML
