@@ -1,23 +1,41 @@
 def docs() -> str:
-    return f"""
+    return """
 Insere um novo atendimento avulso no sistema SIGA para a área de Infraestrutura.
 
+**INSTRUÇÃO PARA O AGENTE IA:**
+ANTES de executar esta função de inserção:
+1. MOSTRE ao usuário TODAS as informações que serão criadas/inseridas no sistema
+2. APRESENTE os dados de forma clara e organizada (datas, descrição, tipo, origem, categoria, equipe, projeto, analista, plaqueta, etc.)
+3. PEÇA confirmação explícita do usuário: "Confirma a criação? (sim/não)"
+4. SÓ EXECUTE esta função se o usuário confirmar explicitamente
+5. Se o usuário não confirmar, cancele a operação e informe que foi cancelada
+
 Esta função cria um novo registro de atendimento avulso independente de qualquer Ordem de Serviço,
 incluindo informações como datas, descrição, tipo, origem, categoria, equipe, projeto e plaqueta.
 Realiza validação de todos os campos obrigatórios e conversão automática de datas.
 
+**ORIENTAÇÃO PARA SOLICITAÇÕES GENÉRICAS:**
+Quando o usuário solicitar "inserir/criar um atendimento" sem especificar o tipo:
+1. **Perguntar qual tipo**: Atendimento OS, Atendimento Avulso Sistemas, ou Atendimento Avulso Infraestrutura
+2. **Se escolher "Avulso"**: Perguntar se é de Sistemas ou Infraestrutura
+3. **Depois de definir o tipo**: Direcionar para a função específica correspondente
+
+Esta função é específica para **Atendimentos Avulso Infraestrutura**. Para outros tipos, use:
+- `inserir_atendimentos_os` (vinculados a OS)  
+- `inserir_atendimento_avulso_sistemas` (área de Sistemas)
+
 **Endpoint utilizado:** `inserirAtendimentoAvulsoSigaIA`
 
 **Estrutura do XML retornado:**
 ```xml
-<atendimentos_avulsos dataIni="2024-01-15 09:00:00" dataFim="2024-01-15 17:00:00"
+<atendimentos_avulsos_infra dataIni="2024-01-15 09:00:00" dataFim="2024-01-15 17:00:00"
                         matSolicitante="123456" tipo="14" descricao="Descrição"
-                        origem="3" equipe="Help Aero" analista="789" projeto="61" categoria="27" plaqueta="222222">
-    <atendimento_avulso sistema="SIGA">
+                        origem="1" equipe="Help Aero" analista="789" projeto="61" categoria="27" plaqueta="222222">
+    <atendimento_avulso_infra sistema="SIGA">
         <status>sucesso</status>
         <mensagem>Atendimento avulso cadastrado com sucesso!</mensagem>
-    </atendimento_avulso>
-</atendimentos_avulsos>
+    </atendimento_avulso_infra>
+</atendimentos_avulsos_infra>
 ```
 
 **Em caso de erro de validação:**
@@ -33,6 +51,44 @@ Realiza validação de todos os campos obrigatórios e conversão automática de
 </erro_validacao>
 ```
 
+**Em caso de erro de validação (analista obrigatório):**
+```xml
+<erro_validacao sistema="SIGA" funcao="inserir_atendimento_avulso_infraestrutura">
+    <erro sistema="SIGA">
+        <status>erro</status>
+        <tipo_erro>analista_obrigatorio</tipo_erro>
+        <campo_invalido>codigo_analista</campo_invalido>
+        <valor_informado>0</valor_informado>
+        <mensagem>Campo 'codigo_analista' é obrigatório e deve ser 'CURRENT_USER' ou um número válido maior que zero. Valor informado: 0</mensagem>
+    </erro>
+</erro_validacao>
+```
+
+**Em caso de erro (dados inválidos):**
+```xml
+<atendimentos_avulsos_infra dataIni="2024-01-15 09:00:00" dataFim="2024-01-15 17:00:00"
+                        matSolicitante="123456" tipo="14" descricao="Descrição"
+                        origem="1" equipe="Help Aero" analista="789" projeto="61" categoria="27" plaqueta="222222">
+    <atendimento_avulso_infra sistema="SIGA">
+        <status>erro</status>
+        <mensagem>Não foi possível salvar o atendimento avulso. Verifique as informações digitadas.</mensagem>
+    </atendimento_avulso_infra>
+</atendimentos_avulsos_infra>
+```
+
+**Em caso de outros erros:**
+```xml
+<atendimentos_avulsos_infra dataIni="2024-01-15 09:00:00" dataFim="2024-01-15 17:00:00"
+                        matSolicitante="123456" tipo="14" descricao="Descrição"
+                        origem="1" equipe="Help Aero" analista="789" projeto="61" categoria="27" plaqueta="222222">
+    <atendimento_avulso_infra sistema="SIGA">
+        <status>erro</status>
+        <mensagem>Erro ao gravar o atendimento avulso. Tente novamente.</mensagem>
+    </atendimento_avulso_infra>
+</atendimentos_avulsos_infra>
+```
+
+
 Args:
     data_inicio (str): Data e hora de início do atendimento avulso.
         Aceita formatos de data ou palavras-chave como "hoje", "agora", "ontem"
@@ -40,7 +96,8 @@ Args:
         Aceita formatos de data ou palavras-chave como "hoje", "agora", "ontem"
     matricula_solicitante (str | Literal["CURRENT_USER"]): Matrícula do usuário que está solicitando o atendimento avulso
     descricao_atendimento (str): Descrição detalhada do atendimento avulso a ser realizado
-    codigo_analista (str | Literal["CURRENT_USER"]): Matrícula do analista/usuário responsável pelo atendimento avulso
+    codigo_analista (str | Literal["CURRENT_USER"]): **[OBRIGATÓRIO]** Matrícula do analista/usuário responsável pelo atendimento avulso.
+    Deve ser "CURRENT_USER" ou um número válido maior que zero. Não aceita valores vazios, "0" ou não-numéricos.
     tipo (Literal): Tipo do atendimento avulso, deve ser um dos valores válidos:
         - "Atividade Interna" (código 19)
         - "Implementação" (código 15)
@@ -53,9 +110,9 @@ Args:
         - "Suporte" (código 14) - padrão
         - "Treinamento" (código 18)
     origem (Literal): Canal/origem do atendimento avulso, deve ser um dos valores válidos:
-        - "E-mail" (código 1)
+        - "E-mail" (código 1) - padrão
         - "Pessoalmente" (código 2)
-        - "Teams" (código 3) - padrão
+        - "Teams" (código 3)
         - "Telefone" (código 4)
         - "WhatsApp" (código 5)
         - "Plantão" (código 7)
@@ -343,7 +400,7 @@ Args:
 Returns:
     str: XML formatado contendo:
         - Em caso de sucesso: confirmação da inserção com status "sucesso"
-        - Em caso de erro de validação: detalhes do erro com valores válidos para o campo inválido
+        - Em caso de erro de validação: detalhes do erro (tipo inválido, analista obrigatório, origem inválida, categoria inválida, etc.)
         - Em caso de erro de API: mensagem de erro específica
         - Em caso de erro interno: mensagem de erro genérica
 
@@ -374,7 +431,7 @@ Examples:
     ...     origem="E-mail",
     ...     categoria="Suporte/Dúvidas/Outros",
     ...     equipe="Help-Desk - Aeroporto",
-    ...     projeto="Operação Help Desk"
+    ...     projeto="Operação Help Desk",
     ...     plaqueta="222222"
     ... )
 
@@ -388,7 +445,19 @@ Examples:
     ...     tipo="Tipo Inexistente"  # Erro!
     ... )
 
+    >>> # Exemplo com codigo_analista inválido (retorna erro)
+    >>> xml = await inserir_atendimento_avulso_infraestrutura(
+    ...     data_inicio="2024-01-15 09:00:00",
+    ...     data_fim="2024-01-15 17:00:00",
+    ...     matricula_solicitante="123456",
+    ...     descricao_atendimento="Teste",
+    ...     codigo_analista="0",  # Erro!
+    ...     tipo="Suporte"
+    ... )
+
 Notes:
+    - **DIFERENCIAÇÃO DE FUNÇÃO**: Esta função cria novos atendimentos avulso infraestrutura. Para editar, use editar_atendimento_avulso_infraestrutura
+    - **VALIDAÇÃO OBRIGATÓRIA**: Campo codigo_analista deve ser "CURRENT_USER" ou um número válido maior que zero (não aceita valores vazios, "0" ou não-numéricos)
     - Esta função é específica para ÁREA INFRAESTRUTURA (área=2)
     - A função realiza validação case-insensitive de todos os campos (tipo, origem, categoria, equipe, projeto)
     - As datas são automaticamente convertidas usando converter_data_siga com manter_horas=True
